@@ -80,7 +80,7 @@ class SuperTorchModel(SuperModel):
         self._num_gpu = TorchUtils.check_available_gpus(show_info=True)
         if self.num_gpu > 0:
             if not self.parser_args.use_cuda:
-                self.log.info("WARNING: You have " + str(self._num_gpu) + " CUDA device, so you should probably run with --cuda")
+                self.log.info("WARNING: You have {self._num_gpu} CUDA device, so you should probably run with --cuda")
                 # 不使用GPU加速
                 self._num_gpu = 0
         else:
