@@ -4,7 +4,7 @@ import time
 from collections import deque
 import ray
 from ray.experimental import async_api
-from skydl.ray.experimental.ray_ring_buffer import RayRingBuffer
+from skydl.ray.ray_ring_buffer import RayRingBuffer
 
 
 
