@@ -24,19 +24,21 @@ class RayStreamingExecutor:
         self._args_parser = args_parser
         logger.info("starting a streaming executor...")
 
-    def execute(self, env=None):
+    def execute(self, env=None, show_logic_dataflow_graph=False, loop_idle_seconds=1):
         try:
             if not env:
                 env = Environment(DefaultStreamingEnvConfigV082(parallelism=self.args_parser.streaming_parallelism))
             stream = self.build_stream(env=env)
-            self.execute_forever(env, stream)
+            self.execute_forever(env, stream, show_logic_dataflow_graph, loop_idle_seconds)
         except Exception as e:
             logger.error(f"RayStreamingExecutor fail on execute(): {e}")
             traceback.print_exc()
 
-    def execute_forever(self, env, stream, loop_idle_seconds=1):
+    def execute_forever(self, env, stream, show_logic_dataflow_graph=False, loop_idle_seconds=1):
         while True:
             try:
+                if show_logic_dataflow_graph:
+                    env.print_logical_graph()
                 # stream to stdout
                 start = time.time()
                 ray.get(env.execute())  # Stay alive until execution finishes
@@ -92,7 +94,7 @@ class RayStreamingExecutor:
         ).set_parallelism(1).map(
             map_fn=handle_record_fn,
             name="nocode_backtest_map"
-        ).set_parallelism(2)
+        )
         return stream
 
 
