@@ -7,7 +7,7 @@ import argparse
 from py_common_util.common.date_utils import DateUtils
 from skydl.ray.streaming_0_8_2.python.operator import OpType, PStrategy
 from skydl.ray.streaming_0_8_2.python.streaming import DataStream, Environment
-from skydl.ray.experimental.ray_ring_buffer import RayRingBuffer
+from skydl.ray.ray_ring_buffer import RayRingBuffer
 from skydl.ray.ray_streaming_executor import RayStreamingExecutor
 from skydl.ray.ray_streaming_util import DefaultStreamingSource, register_custom_serializer, StreamingRecord, \
     DefaultStreamingEnvConfigV082
@@ -72,7 +72,7 @@ class RayStreamingExecutorSample(RayStreamingExecutor):
         def handle_record_fn(record):
             """处理回测的逻辑"""
             logger.info(f"handle_record_fn={record}")
-            time.sleep(10)
+            time.sleep(3)
             logger.info(record.data + ", finished:" + DateUtils.now_to_str())
             return StreamingRecord("ok", "data", "")
 
@@ -81,7 +81,9 @@ class RayStreamingExecutorSample(RayStreamingExecutor):
         ).round_robin(
         ).flat_map(
             splitter_fn
-        ).map(handle_record_fn)
+        ).map(
+            handle_record_fn
+        ).set_parallelism(1)  # 2020-04-11 TODO: 目前V0.8.2只完美支持设置上游>=下游的并行度
         return stream
 
 
@@ -90,21 +92,10 @@ if __name__ == '__main__':
     parser.add_argument("--streaming_parallelism", default=1, type=int, help="ray streaming parallelism")
     args_parser = parser.parse_args()
     ray.init(address="localhost:6379")
-    # register_custom_serializer(StreamingRecord)
-    # register_custom_serializer(OpType)
-    # register_custom_serializer(PStrategy)
-    env = Environment(DefaultStreamingEnvConfigV082(
-        parallelism=args_parser.streaming_parallelism,
-        channel="native"
-    ))
+    register_custom_serializer(StreamingRecord)
+    register_custom_serializer(OpType)
+    register_custom_serializer(PStrategy)
+    env = Environment(DefaultStreamingEnvConfigV082(parallelism=args_parser.streaming_parallelism))
     stream = RayStreamingExecutorSample(
         args_parser=args_parser
-    ).execute(env=env)
-    # stream to stdout
-    start = time.time()
-    env_handle = env.execute()
-    ray.get(env_handle)  # Stay alive until execution finishes
-    env.wait_finish()
-    end = time.time()
-    logger.info("Elapsed time: {} secs".format(end - start))
-    logger.debug("Output stream id: {}".format(stream.id))
\ No newline at end of file
+    ).execute(env)
