@@ -3,6 +3,8 @@ import logging
 import time
 
 import ray
+
+from skydl.ray.ray_streaming_util import DefaultStreamingEnvConfigV082
 from skydl.ray.streaming_0_8_2.python.config import Config
 from skydl.ray.streaming_0_8_2.python.streaming import Environment, Conf
 
@@ -32,16 +34,19 @@ if __name__ == "__main__":
     ray.init(local_mode=False)
 
     # A Ray streaming environment with the default configuration
-    env = Environment(config=Conf(channel_type=Config.NATIVE_CHANNEL))
-
+    # env = Environment(config=Conf(channel_type=Config.NATIVE_CHANNEL))
+    env = Environment(DefaultStreamingEnvConfigV082(
+        parallelism=1,
+        channel="native"
+    ))
     # Stream represents the ouput of the filter and
     # can be forked into other dataflows
     stream = env.read_text_file(args.input_file) \
         .shuffle() \
         .flat_map(splitter) \
-        .set_parallelism(2) \
+        .set_parallelism(1) \
         .filter(filter_fn) \
-        .set_parallelism(2) \
+        .set_parallelism(1) \
         .inspect(lambda x: print("result", x))     # Prints the contents of the
     # stream to stdout
     start = time.time()
