@@ -55,8 +55,10 @@ class Map:
             record = input_gate.pull()
             if record is None:
                 return
+            # 2020-04-11 fixed by tony: map_fn函数必须要无条件执行
+            out_record = self.map_fn(record)
             if output_gate:
-                output_gate.push(self.map_fn(record))
+                output_gate.push(out_record)
             elements += 1
 
 
